package com.ruoyi.project.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.TrsResultsLogMapper;
import com.ruoyi.project.domain.TrsResultsLog;
import com.ruoyi.project.service.ITrsResultsLogService;
import com.ruoyi.common.core.text.Convert;

/**
 * 审校日志Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@Service
public class TrsResultsLogServiceImpl implements ITrsResultsLogService 
{
    @Autowired
    private TrsResultsLogMapper trsResultsLogMapper;

    /**
     * 查询审校日志
     * 
     * @param id 审校日志主键
     * @return 审校日志
     */
    @Override
    public TrsResultsLog selectTrsResultsLogById(Long id)
    {
        return trsResultsLogMapper.selectTrsResultsLogById(id);
    }

    /**
     * 查询审校日志列表
     * 
     * @param trsResultsLog 审校日志
     * @return 审校日志
     */
    @Override
    public List<TrsResultsLog> selectTrsResultsLogList(TrsResultsLog trsResultsLog)
    {
        return trsResultsLogMapper.selectTrsResultsLogList(trsResultsLog);
    }

    /**
     * 新增审校日志
     * 
     * @param trsResultsLog 审校日志
     * @return 结果
     */
    @Override
    public int insertTrsResultsLog(TrsResultsLog trsResultsLog)
    {
        return trsResultsLogMapper.insertTrsResultsLog(trsResultsLog);
    }

    /**
     * 修改审校日志
     * 
     * @param trsResultsLog 审校日志
     * @return 结果
     */
    @Override
    public int updateTrsResultsLog(TrsResultsLog trsResultsLog)
    {
        return trsResultsLogMapper.updateTrsResultsLog(trsResultsLog);
    }

    /**
     * 批量删除审校日志
     * 
     * @param ids 需要删除的审校日志主键
     * @return 结果
     */
    @Override
    public int deleteTrsResultsLogByIds(String ids)
    {
        return trsResultsLogMapper.deleteTrsResultsLogByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除审校日志信息
     * 
     * @param id 审校日志主键
     * @return 结果
     */
    @Override
    public int deleteTrsResultsLogById(Long id)
    {
        return trsResultsLogMapper.deleteTrsResultsLogById(id);
    }
}
